@@ -52,6 +52,7 @@ def leaky_relu(z):
 def load_model():
     """
     Load the default Payne model.
+    Return as PayneModel or PayneModelSet.
     """
 
     datadir = utils.datadir()
@@ -71,7 +72,7 @@ def load_model():
 # Load a single or list of Payne models
 def load_payne_model(mfile):
     """
-    Load a  Payne model from file.
+    Load a Payne model from file.
 
     Returns
     -------
@@ -121,6 +122,7 @@ def load_models():
     """
     Load all Payne models from the Doppler data/ directory
     and return as a DopplerPayneModel.
+    Download the data files, if needed.
 
     Returns
     -------
@@ -137,7 +139,10 @@ def load_models():
     files = glob(datadir+'payne_coolhot_*.npz')
     nfiles = len(files)
     if nfiles==0:
-        raise Exception("No Payne model files in "+datadir)
+        # No Payne model files.  Download them
+        print("No Payne model files in "+datadir+". Downloading them.")
+        utils.download_data()
+        #raise Exception("No Payne model files in "+datadir)
     return DopplerPayneModel.read(files)
 
 def check_params(model,params):
@@ -228,17 +233,19 @@ def prepare_payne_model(model,labels,spec,rv=None,vmacro=None,vsini=None,wave=No
         model.wavevac = spec.wavevac   # this will set things behind the scenes
 
     # Get full wavelength range and total wavelength coverage in the orders
-    owr = dln.minmax(spec.wave)
-    owavefull = dln.valrange(spec.wave)
+    owr = spec.wrange
+    owavefull = dln.valrange(owr)
     owavechunks = 0.0
     odw = np.zeros(spec.norder,np.float64)
     specwave = spec.wave.copy()
+    specmask = spec.mask.copy()    
     if spec.wave.ndim==1:  # make 2D with order in second dimension
         specwave = np.atleast_2d(specwave).T
-    for o in range(spec.norder):
-        owavechunks += dln.valrange(specwave[:,o])
-        odw[o] = np.median(dln.slope(specwave[:,o]))
-
+        specmask = np.atleast_2d(specmask).T
+    for o,sp in enumerate(spec):
+        owavechunks += dln.valrange(sp.wrange)
+        odw[o] = np.median(dln.slope(sp.wave))
+        
     # Check input WAVE array
     if wave is not None:
         if wave.ndim==1:
@@ -254,8 +261,8 @@ def prepare_payne_model(model,labels,spec,rv=None,vmacro=None,vsini=None,wave=No
     if owavechunks > 0.5*owavefull:
         model_all_in_one = True
         wextend = 0.0
-        for o in range(spec.norder):
-            dw = dln.slope(spec.wave[:,o])
+        for o,sp in enumerate(spec):
+            dw = dln.slope(sp.wave)
             dw = np.hstack((dw,dw[-1]))
             dw = np.abs(dw)
             meddw = np.median(dw)
@@ -275,11 +282,16 @@ def prepare_payne_model(model,labels,spec,rv=None,vmacro=None,vsini=None,wave=No
     if wave is not None:
         outmodel.flux = np.zeros(wave.shape,float)
         outmodel.err = np.zeros(wave.shape,float)
-        outmodel.mask = np.zeros(wave.shape,bool)        
+        outmodel.mask = np.ones(wave.shape,bool)        
     lsf_list = []
     lsfwave_list = []
-    for o in range(spec.norder):
-        w = specwave[:,o]
+    for o,sp in enumerate(spec):
+        w = sp.wave
+        m = sp.mask
+        gdpix, = np.where(~m)
+        if len(gdpix)==0:
+            raise ValueError('No unmasked pixels in order ',o)
+        w = w[gdpix]
         w0 = np.min(w)
         w1 = np.max(w)
         dw = dln.slope(w)
@@ -289,7 +301,7 @@ def prepare_payne_model(model,labels,spec,rv=None,vmacro=None,vsini=None,wave=No
         npix = len(w)
         
         if (np.min(model.dispersion)>w0) | (np.max(model.dispersion)<w1):
-                raise Exception('Model does not cover the observed wavelength range')
+            raise Exception('Model does not cover the observed wavelength range')
             
         # Trim
         nextend = int(np.ceil(len(w)*0.25))  # extend 25% on each end
@@ -366,11 +378,21 @@ def prepare_payne_model(model,labels,spec,rv=None,vmacro=None,vsini=None,wave=No
         else:
             omodelflux = interp1d(rmodelwave,cmodelflux,kind='cubic',bounds_error=False,
                                   fill_value=(np.nan,np.nan),assume_sorted=True)(wave[:,o])
-            
-        outmodel.flux[:,o] = omodelflux
 
+        if outmodel.flux.ndim==1:
+            outmodel.flux[0:len(omodelflux)] = omodelflux
+        else:
+            outmodel.flux[0:len(omodelflux),o] = omodelflux        
+            
     if wave is not None:
         outmodel.wave = wave.copy()
+
+    # Change single order 2D arrays to 1D
+    if spec.norder==1:
+        outmodel.flux = outmodel.flux.flatten()
+        outmodel.err = outmodel.err.flatten()        
+        outmodel.wave = outmodel.wave.flatten()
+        outmodel.mask = outmodel.mask.flatten()        
         
     if lsfout is True:
         return outmodel,lsf_list,lsfwave_list
@@ -985,6 +1007,11 @@ class PayneModelSet(object):
                                 fill_value=(np.nan,np.nan),assume_sorted=True)(outwave)
             wavelength = outwave
 
+        # Change single order 2D arrays to 1D
+        if spectrum.ndim==1:
+            spectrum = spectrum.flatten()
+            wavelenth = wavelength.flatten()
+            
         # Return as spectrum object with wavelengths
         if fluxonly is False:
             mspec = Spec1D(spectrum,wave=wavelength,lsfsigma=None,instrument='Model')
