@@ -200,6 +200,7 @@ def spec1d(filename):
     npix = hdu[0].header['NPIX']
     norder = hdu[0].header['NORDER']
     snr = float(hdu[0].header['SNR'])
+    bc = hdu[0].header.get('BC')
     # HDU1: flux
     flux = hdu[1].data
     # HDU2: flux error
@@ -239,9 +240,9 @@ def spec1d(filename):
         spec._cont = cont
     spec.continuum_func = pickle.loads(cont_func_tab['func'][0])
     spec.instrument = instrument
-    #spec.snr = snr
     spec.wavevac = True
-
+    if bc is not None: spec.bc = bc
+    
     # Add extra attributes
     if len(hdu)>8:
         for i in np.arange(8,len(hdu)):
@@ -257,9 +258,8 @@ def spec1d(filename):
                     setattr(spec,c,val)
             elif attribut==True and vector==True:  # vector
                 setattr(spec,name,val)
-
     hdu.close()
-
+    
     return spec
 
 
@@ -817,7 +817,7 @@ def hydra(filename):
         spec.err[0:100] = 1e30
         spec.mask[-100:] = True
         spec.err[-100:] = 1e30        
-            
+        
     return spec
 
     
