@@ -19,7 +19,8 @@ from astropy.coordinates import SkyCoord, EarthLocation
 from astropy.io import fits
 from astropy.table import Table
 import thecannon as tc
-from dlnpyutils import utils as dln, bindata
+from dlnpyutils import utils as dln, bindata, astro
+import matplotlib.pyplot as plt
 import copy
 from . import utils
 from .lsf import GaussianLsf, GaussHermiteLsf
@@ -79,9 +80,8 @@ def continuum(spec,norder=6,perclevel=90.0,binsize=0.1,interp=True):
 
     wave = spec.wave.copy().reshape(spec.npix,spec.norder)   # make 2D
     flux = spec.flux.copy().reshape(spec.npix,spec.norder)   # make 2D
-    err = spec.err.copy().reshape(spec.npix,spec.norder)     # make 2D
     mask = spec.mask.copy().reshape(spec.npix,spec.norder)   # make 2D
-    cont = err.copy()*0.0+1
+    cont = flux.copy()*0.0+1
     for o in range(spec.norder):
         w = wave[:,o].copy()
         wr = [np.min(w),np.max(w)]
@@ -274,12 +274,6 @@ class Spec1D:
                     raise ValueError('All masked pixels in order '+str(i))
                 numpix[i] = np.max(gdpix)+1
         self.numpix = numpix
-        self.npix = np.max(numpix)
-        self.norder = norder
-        if norder==1:
-            self.ndim = 1
-        else:
-            self.ndim = 2
         self.flux = self._merge_multiorder_data(flux,missing_value=0.0)
         if err is not None:
             self.err = self._merge_multiorder_data(err,missing_value=1e30)
@@ -311,7 +305,7 @@ class Spec1D:
         self.lsf = lsfclass[lsftype.lower()](wave=wave,pars=lsfpars,xtype=lsfxtype,lsftype=lsftype,sigma=lsfsigma)
         self.instrument = instrument
         self.filename = filename
-        self.wavevac = wavevac
+        self._wavevac = wavevac
         self.normalized = False
         self.continuum_func = continuum
         self._cont = None
@@ -321,11 +315,47 @@ class Spec1D:
 
     @property
     def size(self):
-        """ Return number of total pixels."""
+        """ Return number of total 'good' pixels (not including buffer pixels)."""
         return np.sum(self.numpix)
 
+    @property
+    def ndim(self):
+        """ Return the number of dimensions."""
+        return self.flux.ndim
+    
+    @property
+    def npix(self):
+        """ Return the number of pixels in each order."""
+        return self.shape[0]
+
+    @property
+    def norder(self):
+        """ Return the number of orders."""
+        if self.ndim==1:
+            return 1
+        else:
+            return self.shape[1]
+    
     def __len__(self):
         return self.norder
+
+    @property
+    def shape(self):
+        return self.flux.shape
+    
+    @property
+    def wrange(self):
+        """ Wavelength range."""
+        wr = [np.inf,-np.inf]
+        if self.wave.ndim==1:
+            w = self.wave[0:self.numpix[0]]
+            wr = [np.min(w),np.max(w)]
+        else:
+            for i in range(self.norder):
+                w = self.wave[0:self.numpix[i],i]
+                wr[0] = np.min([wr[0],np.min(w)])
+                wr[1] = np.max([wr[1],np.max(w)])            
+        return wr
     
     def __getitem__(self,index):
         """
@@ -387,7 +417,139 @@ class Spec1D:
         for n in sdict:
             setattr(ospec,n,sdict[n])
         return ospec
+
+    def __add__(self, value):
+        newspec = self.copy()
+        if isinstance(value,Spec1D):
+            # could interpolate and mask if they don't have the same shape
+            if self.shape != value.shape:
+                raise ValueError('Shapes do not match')
+            newspec.flux += value.flux
+            newspec.err = np.sqrt(newspec.err**2 + value.err**2)
+            newspec.mask = np.bitwise_or.reduce((newspec.mask,value.mask))
+        else:
+            newspec.flux += value
+        return newspec
+        
+    def __iadd__(self, value):
+        if isinstance(value,Spec1D):
+            if self.shape != value.shape:
+                raise ValueError('Shapes do not match')            
+            self.flux += value.flux
+        else:
+            self.flux += value
+        return self
+        
+    def __radd__(self, value):
+        return self + value
+        
+    def __sub__(self, value):
+        newspec = self.copy()
+        if isinstance(value,Spec1D):
+            if self.shape != value.shape:
+                raise ValueError('Shapes do not match')
+            newspec.flux -= value.flux
+            newspec.err = np.sqrt(newspec.err**2 + value.err**2)
+            newspec.mask = np.bitwise_or.reduce((newspec.mask,value.mask))
+        else:
+            newspec.flux -= value
+        return newspec
+              
+    def __isub__(self, value):
+        if isinstance(value,Spec1D):
+            if self.shape != value.shape:
+                raise ValueError('Shapes do not match')            
+            self.flux -= value.flux
+        else:
+            self.flux -= value
+        return self
+         
+    def __rsub__(self, value):
+        return self - value        
     
+    def __mul__(self, value):
+        newspec = self.copy()
+        if isinstance(value,Spec1D):
+            if self.shape != value.shape:
+                raise ValueError('Shapes do not match')
+            newspec.flux *= value.flux
+            newspec.err *= value.flux
+            newspec.mask = np.bitwise_or.reduce((newspec.mask,value.mask))
+        else:
+            newspec.flux *= value
+            newspec.err *= value            
+        return newspec
+               
+    def __imul__(self, value):
+        if isinstance(value,Spec1D):
+            if self.shape != value.shape:
+                raise ValueError('Shapes do not match')            
+            self.flux *= value.flux
+            self.err *= value.flux            
+        else:
+            self.flux *= value
+            self.err *= value            
+        return self
+    
+    def __rmul__(self, value):
+        return self * value
+               
+    def __truediv__(self, value):
+        newspec = self.copy()
+        if isinstance(value,Spec1D):
+            if self.shape != value.shape:
+                raise ValueError('Shapes do not match')
+            newspec.flux /= value.flux
+            newspec.err /= value.flux
+            newspec.mask = np.bitwise_or.reduce((newspec.mask,value.mask))
+        else:
+            newspec.flux /= value
+            newspec.err /= value            
+        return newspec
+      
+    def __itruediv__(self, value):
+        if isinstance(value,Spec1D):
+            if self.shape != value.shape:
+                raise ValueError('Shapes do not match')            
+            self.flux /= value.flux
+            self.err /= value.flux            
+        else:
+            self.flux /= value
+            self.err /= value            
+        return self
+      
+    def __rtruediv__(self, value):
+        return self / value
+
+    @property
+    def wavevac(self):
+        """ Whether wavelengths are in vacuum units."""
+        return self._wavevac
+    
+    @wavevac.setter
+    def wavevac(self,wavevac):
+        """ Set/change wavelength wavevac value."""
+        # Convert wavelength from air->vacuum or vice versa
+        if self._wavevac != wavevac:
+            for i in range(self.norder):
+                npix = self.numpix[i]
+                if self.ndim==1:
+                    w = self.wave[0:npix]
+                else:
+                    w = self.wave[0:npix,i]                    
+                # Air -> Vacuum
+                if wavevac is True:
+                    wnew = astro.airtovac(w)
+                # Vacuum -> Air
+                else:
+                    wnew = astro.vactoair(w)
+                if self.ndim==1:
+                    self.wave[0:npix] = wnew
+                else:
+                    self.wave[0:npix,i] = wnew
+            # change the wavevac value
+            self._wavevac = wavevac
+                    
     def _info_from_input(self,data):
         """ Figure out the number of orders, number of pixels for each order, and data type for input multi-order data."""
         if type(data) in [list,tuple]:
@@ -446,10 +608,6 @@ class Spec1D:
             s += "Wave = "+str(self.wave)
         return s
 
-    @property
-    def shape(self):
-        return self.npix,self.norder
-    
     @property
     def snr(self):
         """ Return the S/N"""
@@ -753,7 +911,32 @@ class Spec1D:
         # If the LSF is in pixel units, then it won't work right.
         ospec._child = True
         return ospec
-        
+
+    def plot(self,ax=None,c=None,masked=True):
+        """ Plot the spectrum dealing with buffer and masked pixels and keeping color constant for all orders."""
+        if ax is None:
+            ax = plt
+            
+        """ Plot the spectrum."""
+        for i in range(self.norder):
+            npix = self.numpix[i]                
+            if self.ndim==1:
+                w = self.wave[0:npix]
+                f = self.flux[0:npix]
+                m = self.mask[0:npix]
+            else:
+                w = self.wave[0:npix,i]
+                f = self.flux[0:npix,i]
+                m = self.mask[0:npix,i]
+            if masked:
+                f = f.copy()
+                f[m] = np.nan
+            
+            if i==0:
+                line1, = ax.plot(w,f)
+            else:
+                line, = ax.plot(w,f,c=line1.get_color())              
+    
     def copy(self):
         """ Create a new copy."""
         if self.lsf.pars is not None:
@@ -826,7 +1009,7 @@ class Spec1D:
         ckeys = ['flux','err','wave','mask','lsf','instrument','wavevac','normalized',
                  'ndim','npix','norder','snr','barycorr','continuum_func','copy','filename',
                  'interp','normalize','pix2wave','reader','wave2pix','write','cont','flatten',
-                 'head','bc','size','numpix']
+                 'head','bc','size','numpix','shape','plot','wrange']
         for a in attributes:
             if a.lower() not in ckeys and a[0]!='_':
                 val = getattr(self,a)
@@ -922,7 +1105,7 @@ class Spec1D:
         hdu[7].header['BUNIT'] = 'Continuum function'
         # Add other attributes to the primary header
         #   these were added by the user
-        sdict,vdic = self._userattributes
+        sdict,vdict = self._userattributes
         nexten = 8
         # Put scalars in a separate table
         if len(sdict)>0:
